@@ -78,7 +78,7 @@ class Education:
 
     @staticmethod
     def from_pdl(pdl_input: dict[str, any]) -> Optional['Education']:
-        school = pdl_input.get('school', {})
+        school = pdl_input.get('school', {}) or {}
         start_date = pdl_input.get('start_date')
         end_date = pdl_input.get('end_date')
         return Education(
